@@ -24,9 +24,16 @@ import xml.etree.ElementTree as ET
 from aicspylibczi import CziFile
 from aicsimageio import AICSImage
 import dateutil.parser as dt
-from czitools import pylibczirw_metadata as czimd
+#from czitools import pylibczirw_metadata as czimd
+import czitools
 from tqdm.contrib.itertools import product
 from typing import List, Dict, Tuple, Optional, Type, Any, Union
+import logging
+
+_logger: Optional[logging.Logger] = None
+# configure logging
+#set_logger(name="czitools-logging", level=logging.DEBUG)
+#logger = get_logger()
 
 
 def openfile(directory: str,
@@ -135,8 +142,8 @@ def md2dataframe(md_dict: Dict,
                  keycol: str = "Value") -> pd.DataFrame:
     """Convert the metadata dictionary to a Pandas DataFrame.
 
-    :param metadata: MeteData dictionary
-    :type metadata: dict
+    :param md_dict: MeteData dictionary
+    :type md_dict: dict
     :param paramcol: Name of Columns for the MetaData Parameters, defaults to "Parameter"
     :type paramcol: str, optional
     :param keycol: Name of Columns for the MetaData Values, defaults to "Value"
@@ -173,13 +180,15 @@ def addzeros(number: int) -> str:
     :rtype: str
     """
 
+    zerostring = None
+
     if number < 10:
         zerostring = '0000' + str(number)
-    if number >= 10 and number < 100:
+    if 10 <= number < 100:
         zerostring = '000' + str(number)
-    if number >= 100 and number < 1000:
+    if 100 <= number < 1000:
         zerostring = '00' + str(number)
-    if number >= 1000 and number < 10000:
+    if 1000 <= number < 10000:
         zerostring = '0' + str(number)
 
     return zerostring
@@ -209,15 +218,13 @@ def get_fname_woext(filepath: str) -> str:
     return filepath_woext
 
 
-def check_dimsize(mdata_entry: Union[int, None], set2value: int = 1) -> int:
+def check_dimsize(mdata_entry: Union[int, None], set2value: int = 1) -> Union[int, None]:
 
     # check if the dimension entry is None
     if mdata_entry is None:
-        size = set2value
+        return set2value
     if mdata_entry is not None:
-        size = mdata_entry
-
-    return size
+        return mdata_entry
 
 
 def get_daskstack(aics_img: AICSImage) -> List:
@@ -236,10 +243,11 @@ def get_planetable(czifile: str,
                    norm_time: bool = True,
                    savetable: bool = False,
                    separator: str = ',',
+                   read_one_only: bool = False,
                    index: bool = True) -> Tuple[pd.DataFrame, Optional[str]]:
 
     # get the czi metadata
-    metadata = czimd.CziMetadata(czifile)
+    czi_dimensions = czitools.pylibczirw_metadata.CziDimensions(czifile)
     aicsczi = CziFile(czifile)
 
     # initialize the plane table
@@ -262,11 +270,11 @@ def get_planetable(czifile: str,
     sbcount = -1
 
     # check if dimensions are None (because they do not exist for that image)
-    sizeC = check_dimsize(metadata.image.SizeC, set2value=1)
-    sizeZ = check_dimsize(metadata.image.SizeZ, set2value=1)
-    sizeT = check_dimsize(metadata.image.SizeT, set2value=1)
-    sizeS = check_dimsize(metadata.image.SizeS, set2value=1)
-    sizeM = check_dimsize(metadata.image.SizeM, set2value=1)
+    size_c = check_dimsize(czi_dimensions.SizeC, set2value=1)
+    size_z = check_dimsize(czi_dimensions.SizeZ, set2value=1)
+    size_t = check_dimsize(czi_dimensions.SizeT, set2value=1)
+    size_s = check_dimsize(czi_dimensions.SizeS, set2value=1)
+    size_m = check_dimsize(czi_dimensions.SizeM, set2value=1)
 
     def getsbinfo(subblock: Any) -> Tuple[float, float, float, float]:
         try:
@@ -296,14 +304,14 @@ def get_planetable(czifile: str,
 
         return timestamp, xpos, ypos, zpos
 
-    # in case the CZI has the M-Dimension
-    if metadata.ismosaic:
+    # do if the data is not a mosaic
+    if size_m > 1:
 
-        for s, m, t, z, c in product(range(sizeS),
-                                     range(sizeM),
-                                     range(sizeT),
-                                     range(sizeZ),
-                                     range(sizeC)):
+        for s, m, t, z, c in product(range(size_s),
+                                     range(size_m),
+                                     range(size_t),
+                                     range(size_z),
+                                     range(size_c)):
             sbcount += 1
             print("Reading sublock : ", sbcount)
 
@@ -326,22 +334,6 @@ def get_planetable(czifile: str,
             # get information from subblock
             timestamp, xpos, ypos, zpos = getsbinfo(sb)
 
-            # df_czi = df_czi.append({'Subblock': sbcount,
-            #                         'Scene': s,
-            #                         'Tile': m,
-            #                         'T': t,
-            #                         'Z': z,
-            #                         'C': c,
-            #                         'X[micron]': xpos,
-            #                         'Y[micron]': ypos,
-            #                         'Z[micron]': zpos,
-            #                         'Time[s]': timestamp,
-            #                         'xstart': tilebbox.x,
-            #                         'ystart': tilebbox.y,
-            #                         'width': tilebbox.w,
-            #                         'height': tilebbox.h},
-            #                         ignore_index=True)
-
             plane = pd.DataFrame({'Subblock': sbcount,
                                   'Scene': s,
                                   'Tile': m,
@@ -360,12 +352,16 @@ def get_planetable(czifile: str,
 
             df_czi = pd.concat([df_czi, plane], ignore_index=True)
 
-    if not metadata.ismosaic:
+            if read_one_only:
+                break
 
-        for s, t, z, c in product(range(sizeS),
-                                  range(sizeT),
-                                  range(sizeZ),
-                                  range(sizeC)):
+    # do if the data is not a mosaic
+    if size_m == 1:
+
+        for s, t, z, c in product(range(size_s),
+                                  range(size_t),
+                                  range(size_z),
+                                  range(size_c)):
             sbcount += 1
 
             # get x, y, width and height for a specific tile
@@ -385,22 +381,6 @@ def get_planetable(czifile: str,
             # get information from subblock
             timestamp, xpos, ypos, zpos = getsbinfo(sb)
 
-            # df_czi = df_czi.append({'Subblock': sbcount,
-            #                         'Scene': s,
-            #                         'Tile': 0,
-            #                         'T': t,
-            #                         'Z': z,
-            #                         'C': c,
-            #                         'X[micron]': xpos,
-            #                         'Y[micron]': ypos,
-            #                         'Z[micron]': zpos,
-            #                         'Time[s]': timestamp,
-            #                         'xstart': tilebbox.x,
-            #                         'ystart': tilebbox.y,
-            #                         'width': tilebbox.w,
-            #                         'height': tilebbox.h},
-            #                        ignore_index=True)
-
             plane = pd.DataFrame({'Subblock': sbcount,
                                   'Scene': s,
                                   'Tile': 0,
@@ -417,9 +397,11 @@ def get_planetable(czifile: str,
                                   'height': tilebbox.h},
                                  index=[0])
 
-            #df_czi = pd.concat([df_czi, plane], ignore_index=True)
             df_czi = pd.concat([df_czi, plane], ignore_index=True)
 
+            if read_one_only:
+                break
+
     # cast data  types
     df_czi = df_czi.astype({'Subblock': 'int32',
                             'Scene': 'int32',
@@ -548,3 +530,37 @@ def expand5d(array):
     array5d = np.expand_dims(array, axis=-5)
 
     return array5d
+
+
+def get_logger() -> logging.Logger:
+    global _logger
+    if _logger is None:
+        raise RuntimeError('get_logger call made before logger was setup!')
+    return _logger
+
+
+def set_logger(name: str, level=logging.DEBUG) -> None:
+    global _logger
+
+    # check if logger already exists
+    if _logger is not None:
+        raise RuntimeError('_logger is already setup!')
+
+    _logger = logging.getLogger(name)
+    _logger.handlers.clear()
+    _logger.setLevel(level)
+    ch = logging.StreamHandler()
+    ch.setLevel(level)
+
+    # get the logging format
+    ch.setFormatter(_get_formatter())
+    _logger.addHandler(ch)
+    _logger.propagate = False  # otherwise root logger prints things again
+
+
+def _get_formatter() -> logging.Formatter:
+
+    #logfmt = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s: %(message)s")
+    logfmt = logging.Formatter("%(asctime)s - %(levelname)s: %(message)s")
+
+    return logfmt
